#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MINNUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MINNUM_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/minnum.hpp>

#endif
